#!/usr/bin/perl -w

# http://sf.net/tracker/?func=detail&aid=2892923&group_id=127642&atid=709065

# mbox2eml 0.1.1 does not set the modification time of the extracted
# .eml files to the timestamp of the message; this script does that.
# Run it on a directory containing .eml files.

use strict;
use Date::Parse qw(str2time);
use File::Spec::Functions qw(catfile);
use Mail::Internet qw();

if (!@ARGV) {
  print STDERR "Usage: $0 DIR\n";
  exit 1;
}

opendir(DIR, $ARGV[0]) || die("Can't open dir '$ARGV[0]': $!");

for my $eml (grep { /^.+\.eml$/ && -f catfile($ARGV[0], $_) } readdir(DIR)) {
  $eml = catfile($ARGV[0], $eml);
  if (!open(EML, $eml)) {
    warn("Can't open file '$eml' for reading: $!\n");
    next;
  }

  my $mail = Mail::Internet->new(*EML, Body => []);
  close(EML) || warn("Can't close file '$eml': $!\n");

  my $date = $mail->head->get("Date");
  if (!$date) {
    warn("No Date found in file '$eml', skipped\n");
    next;
  }

  $date = str2time($date);
  if (!$date) {
    warn("Can't parse date '$date', skipped\n");
    next;
  }

  utime($date, $date, $eml) || warn("Can't set times for file '$eml': $!\n");
}

closedir(DIR) || warn("Can't close dir $ARGV[0]: $!");
